@@ -4,6 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
+#include "mapcsselementstate.h"
 #include "mapcssselector_p.h"
 #include "mapcsscondition_p.h"
 #include "mapcssresult.h"
@@ -56,6 +57,10 @@ bool MapCSSBasicSelector::matches(const MapCSSState &state, MapCSSResult &result
         return false;
     }
 
+    if (m_elementState && (state.state & m_elementState) == 0) {
+        return false;
+    }
+
     if (std::all_of(conditions.begin(), conditions.end(), [&state](const auto &cond) { return cond->matches(state); })) {
         result.applyDeclarations(m_layer, declarations);
         return true;
@@ -130,6 +135,13 @@ void MapCSSBasicSelector::write(QIODevice *out) const
         cond->write(out);
     }
 
+    if (m_elementState & MapCSSElementState::Active) {
+        out->write(":active");
+    }
+    if (m_elementState & MapCSSElementState::Hovered) {
+        out->write(":hovered");
+    }
+
     if (!m_layer.isNull()) {
         out->write("::");
         out->write(m_layer.name());
@@ -166,6 +178,17 @@ void MapCSSBasicSelector::setClass(ClassSelectorKey key)
     m_class = key;
 }
 
+void MapCSSBasicSelector::setPseudoClass(const char *str, std::size_t len)
+{
+    if (std::strncmp(str, "active", len) == 0) {
+        m_elementState |= MapCSSElementState::Active;
+    } else if (std::strncmp(str, "hovered", len) == 0) {
+        m_elementState |= MapCSSElementState::Hovered;
+    } else {
+        qWarning() << "Unhandled pseudo class:" << QByteArrayView(str, (qsizetype)len);
+    }
+}
+
 void MapCSSBasicSelector::setLayer(LayerSelectorKey key)
 {
     m_layer = key;
